==> snipe-it-7.1.17.zip: snipe-it-7.1.17/resources/lang/sr-CS/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'O lokacijama',
    'about_locations'           => 'Lokacije se upotrebljavaju za praćenje podataka o lokaciji korisnika, imovine i ostalih stavki',
    'assets_rtd'                => 'Imovina', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Dodeljene imovine',
    'id'                        => 'ID',
    'city'                      => 'Grad',
    'state'                     => 'Država',
    'country'                   => 'Zemlja',
    'create'                    => 'Kreiraj lokaciju',
    'update'                    => 'Ažuriraj lokaciju',
    'print_assigned'            => 'Oštampaj zaduženo',
    'print_all_assigned'        => 'Oštampaj sve zaduženo',
    'name'                      => 'Naziv lokacije',
    'address'                   => 'Adresa',
    'address2'                   => 'Adresa 2',
    'zip'                       => 'Poštanski broj',
    'locations'                 => 'Lokacije',
    'parent'                    => 'Parent',
    'currency'                  => 'Valuta lokacije',
    'ldap_ou'                   => 'LDAP pretraživanje OU',
    'user_name'                 => 'Korisničko ime',
    'department'                => 'Sektor',
    'location'                  => 'Lokacija',
    'asset_tag'                 => 'Naziv osnovnog sredstva',
    'asset_name'                => 'Naziv',
    'asset_category'            => 'Kategorija',
    'asset_manufacturer'        => 'Proizvođač',
    'asset_model'               => 'Model',
    'asset_serial'              => 'Serijski broj',
    'asset_location'            => 'Lokacija',
    'asset_checked_out'         => 'Zaduženo',
    'asset_expected_checkin'    => 'Očekivano razduživanje',
    'date'                      => 'Datum:',
    'phone'                     => 'Telefon lokacije',
    'signed_by_asset_auditor'   => 'Odobrio:',
    'signed_by_finance_auditor' => 'Obodrio:',
    'signed_by_location_manager' => 'Odobio:',
    'signed_by'                 => 'Signed Off By:',
];

==> snipe-it-8.3.3.zip: snipe-it-8.3.3/resources/lang/sr-CS/admin/locations/table.php <==
<?php

return [
    'about_locations_title'     => 'O lokacijama',
    'about_locations'           => 'Lokacije se upotrebljavaju za praćenje podataka o lokaciji korisnika, imovine i ostalih stavki',
    'assets_rtd'                => 'Imovina', // This has NEVER meant Assets Retired. I don't know how it keeps getting reverted.
    'assets_checkedout'         => 'Dodeljene imovine',
    'id'                        => 'ID',
    'city'                      => 'Grad',
    'state'                     => 'Država',
    'country'                   => 'Zemlja',
    'create'                    => 'Kreiraj lokaciju',
    'update'                    => 'Ažuriraj lokaciju',
    'print_assigned'            => 'Oštampaj zaduženo',
    'print_inventory'           => 'Oštampaj inventar',
    'print_all_assigned'        => 'Ostampaj inventar i zaduženo',
    'name'                      => 'Naziv lokacije',
    'address'                   => 'Adresa',
    'address2'                   => 'Adresa 2',
    'zip'                       => 'Poštanski broj',
    'locations'                 => 'Lokacije',
    'parent'                    => 'Parent',
    'currency'                  => 'Valuta lokacije',
    'ldap_ou'                   => 'LDAP pretraživanje OU',
    'user_name'                 => 'Korisničko ime',
    'department'                => 'Sektor',
    'location'                  => 'Lokacija',
    'asset_tag'                 => 'Naziv osnovnog sredstva',
    'asset_name'                => 'Naziv',
    'asset_category'            => 'Kategorija',
    'asset_manufacturer'        => 'Proizvođač',
    'asset_model'               => 'Model',
    'asset_serial'              => 'Serijski broj',
    'asset_location'            => 'Lokacija',
    'asset_checked_out'         => 'Zaduženo',
    'asset_expected_checkin'    => 'Očekivano razduživanje',
    'date'                      => 'Datum:',
    'phone'                     => 'Telefon lokacije',
    'signed_by_asset_auditor'   => 'Odobrio:',
    'signed_by_finance_auditor' => 'Obodrio:',
    'signed_by_location_manager' => 'Odobio:',
    'signed_by'                 => 'Signed Off By:',
    'clone'  					=> 'Kloniraj lokaciju',
];
